# {{DATE}}

*Use rapid logging: • Task | ○ Event | ─ Note*

## Daily Log

### Tasks
- [ ]
- [ ]
- [ ]

### Events
○


### Notes
─


## Signifiers
*Mark important items*

`*` Important | `!` Inspiration | `👁` Explore further


## Migration
*Tasks to migrate from yesterday*


## Evening Review

### Completed
- [x]


### Migrated to Tomorrow
→


### Not Worth It (Struck Through)
~~Task~~


---

*Keep it simple. Capture quickly. Review regularly.*
